@@ -8,7 +8,7 @@ use warnings;
 my $VERSION="%{VERSION}";
 
 #For CVS , use following line
-#my $VERSION=sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+#my $VERSION=sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 sub do_something {
   my $text=shift;
@@ -22,11 +22,11 @@ __END__
 
 =head1 NAME
 
-%{APPNAME} - short discription of your program
+%{APPNAME} - short description of your program
 
 =head1 SYNOPSIS
 
- how to us your program
+ how to use your program
 
 =head1 DESCRIPTION
 
