@@ -31,7 +31,7 @@
 #include "statusbar.h"
 #include "partcontroller.h"
 
-StatusBar::StatusBar(QWidget *parent, const char *name)
+KDevStatusBar::KDevStatusBar(QWidget *parent, const char *name)
     : KStatusBar(parent, name), _cursorIface(0), _activePart(0)
 {
 	QWidget * w = new QWidget( this );
@@ -45,63 +45,46 @@ StatusBar::StatusBar(QWidget *parent, const char *name)
 
 	connect(PartController::getInstance(), SIGNAL(activePartChanged(KParts::Part*)),
 		this, SLOT(activePartChanged(KParts::Part*)));
-
-	/// @todo remove parts from the map on PartRemoved() ?
 }
 
 
-StatusBar::~StatusBar()
+KDevStatusBar::~KDevStatusBar()
 {}
 
-void StatusBar::activePartChanged(KParts::Part *part)
+void KDevStatusBar::activePartChanged(KParts::Part *part)
 {
 	if ( _activePart && _activePart->widget() )
 		disconnect( _activePart->widget(), 0, this, 0 );
 
 	_activePart = part;
 	_cursorIface = 0;
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,0)
 	_viewmsgIface = 0;
-# endif
-#endif
   
 	if (part && part->widget())
 	{
-
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,0)
-	if ((_viewmsgIface = dynamic_cast<KTextEditor::ViewStatusMsgInterface*>(part->widget())))
-	{
-		connect( part->widget(), SIGNAL( viewStatusMsg( const QString & ) ),
-			this, SLOT( setStatus( const QString & ) ) );
-
-#  if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
-		_status->setText( _map[ _activePart ] );
-#  endif
-
-		_status->show();
+		if ((_viewmsgIface = dynamic_cast<KTextEditor::ViewStatusMsgInterface*>(part->widget())))
+		{
+			connect( part->widget(), SIGNAL( viewStatusMsg( const QString & ) ),
+				this, SLOT( setStatus( const QString & ) ) );
+	
+			_status->show();
+		}
+		else if ((_cursorIface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget())))
+		{
+			connect(part->widget(), SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
+	
+			_status->show();
+			cursorPositionChanged();
+		}
+		else
+		{
+			// we can't produce any status data, hide the status box
+			_status->hide();
+		}
 	}
-	else
-# endif
-#endif
-	if ((_cursorIface = dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget())))
-    {
-		connect(part->widget(), SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
-
-		_status->show();
-		cursorPositionChanged();
-    }
-	else
-	{
-		// we can't produce any status data, hide the status box
-		_status->hide();
-	}
-  }
 }
 
-
-void StatusBar::cursorPositionChanged()
+void KDevStatusBar::cursorPositionChanged()
 {
   if (_cursorIface)
   {
@@ -111,24 +94,18 @@ void StatusBar::cursorPositionChanged()
   }
 }
 
-void StatusBar::setStatus(const QString &str)
+void KDevStatusBar::setStatus(const QString &str)
 {
 	_status->setText(str);
-
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
-	_map[_activePart] = str;
-# endif
-#endif
 }
 
 
-void StatusBar::setCursorPosition(int line, int col)
+void KDevStatusBar::setCursorPosition(int line, int col)
 {
 	_status->setText(i18n(" Line: %1 Col: %2 ").arg(line+1).arg(col));
 }
 
-void StatusBar::addWidget ( QWidget *widget, int stretch, bool permanent)
+void KDevStatusBar::addWidget ( QWidget *widget, int stretch, bool permanent)
 {
 	KStatusBar::addWidget(widget,stretch,permanent);
 
